# BlackDuck

BlackDuck is a game commonly known as blackjack. I switched all the jacks with ducks (text) and added the most common actions, hitting, standing, doubling down and spliting. The game is made susing Python and main game in inclosed in a menu where you can see information, change settings and regroup youer money.

## Features

- Blackjack - A great gambling game
- Advanced Blackjack features - Double down, split
- Scoring based system - Scores score based of how much money won
- ATM system - When running out of money you can go to the atm and withdraw money
- Settings function - Changable options for your preference
- Information section - A space for understand and learn about the game and how to play
- Typewriter - All text is printed out as a typewriter effect

## How to play BlackDuck

1) Go to [https://pypi.org/project/blackduck_game/](https://pypi.org/project/blackduck_game/)

2) once at PyPi, copy the package installation or "pip install blackduck_game"

3) Open Terminal or Command Prompt with python and pip installed. You can check this by using:

    ```sh
    python --version
    ```

    or

    ```sh
    python3 --version
    ```

    and

    ```sh
    pip3 --version
    ```

    or

    ```sh
    pip --version
    ```

4) Use one of the commands (depending on OS and python type)

   ```sh
   pip install blackduck_game
   ```

   ```sh
   pip3 install blackduck_game
   ```

   ```sh
   pipx install blackduck_game
   ```

   ```sh
   python3 -m pip install blackduck_game
   ```

5) Use the command `blackduck` to play the game

6) Start playing and have fun gambling